/*
* PubMatic Inc. ("PubMatic") CONFIDENTIAL
* Unpublished Copyright (c) 2006-2021 PubMatic, All Rights Reserved.
*
* NOTICE:  All information contained herein is, and remains the property of
* PubMatic. The intellectual and technical concepts contained herein are
* proprietary to PubMatic and may be covered by U.S. and Foreign Patents,
* patents in process, and are protected by trade secret or copyright law.
* Dissemination of this information or reproduction of this material is
* strictly forbidden unless prior written permission is obtained from PubMatic.
* Access to the source code contained herein is hereby forbidden to anyone
* except current PubMatic employees, managers or contractors who have executed
* Confidentiality and Non-disclosure agreements explicitly covering such access
* or to such other persons whom are directly authorized by PubMatic to access
* the source code and are subject to confidentiality and nondisclosure
* obligations with respect to the source code.
*
* The copyright notice above does not evidence any actual or intended
* publication or disclosure  of  this source code, which includes information
* that is confidential and/or proprietary, and is a trade secret, of  PubMatic.
* ANY REPRODUCTION, MODIFICATION, DISTRIBUTION, PUBLIC  PERFORMANCE, OR PUBLIC
* DISPLAY OF OR THROUGH USE  OF THIS  SOURCE CODE  WITHOUT  THE EXPRESS WRITTEN
* CONSENT OF PUBMATIC IS STRICTLY PROHIBITED, AND IN VIOLATION OF APPLICABLE
* LAWS AND INTERNATIONAL TREATIES.  THE RECEIPT OR POSSESSION OF  THIS SOURCE
* CODE AND/OR RELATED INFORMATION DOES NOT CONVEY OR IMPLY ANY RIGHTS TO
* REPRODUCE, DISCLOSE OR DISTRIBUTE ITS CONTENTS, OR TO MANUFACTURE, USE, OR
* SELL ANYTHING THAT IT  MAY DESCRIBE, IN WHOLE OR IN PART.
*/

#import <OpenWrapSDK/POBRewardedAdEvent.h>

NS_ASSUME_NONNULL_BEGIN
/*!
 @abstract Defines optional request parameters to be used to create MoPub rewarded ad with.
 */
@interface POBMPRequestParameters : NSObject
/*!
 @abstract Initializes request parameters with the given values.
 @param keywords A string representing a set of non-personally identifiable keywords that should be passed to the MoPub ad server to receive more relevant advertising.
 @param userDataKeywords A string representing a set of personally identifiable keywords that should be passed to the MoPub ad server to receive
 more relevant advertising.
 @param customerId This is the ID given to the user by the publisher to identify them in their app
 @param localExtras An optional dictionary containing extra local data.
 @return POBMPRequestParameters instance
 */
- (instancetype)initWithKeywords:(NSString*_Nullable)keywords
                userDataKeywords:(NSString*_Nullable)userDataKeywords
                      customerId:(NSString*_Nullable)customerId
                     localExtras:(NSDictionary*_Nullable)localExtras;
@end

typedef POBMPRequestParameters* _Nullable (^POBMPRewardedConfigBlock)(POBBid * _Nonnull bid);

/*!
 This class is responsible for communication between OpenWrap rewarded ad and Mopub rewarded video.
 It implements the POBRewardedAdEvent protocol. It notifies events back to OpenWrap SDK using POBRewardedAdEventDelegate methods
 */
@interface MoPubRewardedEventHandler : NSObject<POBRewardedAdEvent>
/*!
 @abstract Creates a handler instance for a given ad unit
 @discussion This is a convenient way of creating single handler instance for rewarded ads.
 @note The handler created using this method will be mapped to the given ad unit. New requests for same ad unit will return the mapped handler instance.
 @param adUnit MoPub rewarded video ad unit id
 @return rewarded handler instance
 */
+ (MoPubRewardedEventHandler*_Nullable)handlerWithAdUnitId:(NSString*)adUnit;

/*!
 @warning Use 'handlerWithAdUnitId' instead of default init
 */
- (instancetype)init NS_UNAVAILABLE;

/*!
 A configBlock that is called before event handler makes an ad request call to Mopub SDK. It receives MPInterstitialAdController as parameter, which will be used to make the ad request.
 */
@property (nonatomic, copy) POBMPRewardedConfigBlock configBlock;

@end

NS_ASSUME_NONNULL_END
